import 'reflect-metadata';
import { ValidationProperty } from "../model/validate/ValidationProperty";
import { AnnotationBean, AnnotationMapping, AnnotationModel } from "../model/AnnotationModel";
/**
 *  // 获取成员类型
 let type = Reflect.getMetadata('design:type', target, propertyName)
 // 获取成员参数类型
 let paramtypes = Reflect.getMetadata('design:paramtypes', target, propertyName)
 // 获取成员返回类型
 let returntype = Reflect.getMetadata('design:returntype', target, propertyName)
 */
/**
 *  标识是一个controller层
 * @param value 值
 * @param annotationModel
 * @constructor
 */
export declare function Controller(value: string, annotationModel?: AnnotationModel): (target: Object) => void;
/**
 * 删除请求
 * @param value 删除的路径
 * @constructor
 */
export declare function DeleteMapping(value: string, annotationMapping?: AnnotationMapping): (target: Object | Function, propertyKey: string, descriptor: PropertyDescriptor) => void;
/**
 * get请求
 * @param value 请求路径
 * @param annotationMapping
 * @constructor
 */
export declare function GetMapping(value: string, annotationMapping?: AnnotationMapping): (target: any, propertyKey: string, descriptor: PropertyDescriptor) => void;
/**
 *  Patch请求
 * @param value 请求路径
 * @param annotationMapping
 * @constructor
 */
export declare function PatchMapping(value: string, annotationMapping?: AnnotationMapping): (target: any, propertyKey: string, descriptor: PropertyDescriptor) => void;
/**
 *  Post请求
 * @param value 请求路径
 * @constructor
 */
export declare function PostMapping(value: string, annotationMapping?: AnnotationMapping): (target: any, propertyKey: string, descriptor: PropertyDescriptor) => void;
/**
 *  Put请求
 * @param value 请求路径
 * @constructor
 */
export declare function PutMapping(value: string, annotationMapping?: AnnotationMapping): (target: Object, propertyKey: string, descriptor: PropertyDescriptor) => void;
/**
 * RequestMapping请求
 * @param value 请求路径
 * @param group api分组
 * @constructor
 */
export declare function RequestMapping(value: string, annotationMapping?: AnnotationMapping): (target: Object, propertyKey: string, descriptor: PropertyDescriptor) => void;
/**
 * Service标识
 * @param value service名称  默认当前类名称
 * @constructor
 */
export declare function Service(value?: string): (target: Object) => void;
/**
 * Component标识
 * @param value service名称  默认当前类名称
 * @constructor
 */
export declare function Component(value?: string): (target: Object) => void;
/**
 * 参数注解
 * @param message
 * @param property 验证属性
 * @constructor
 */
export declare function Param(message: string, property?: Array<ValidationProperty>): (target: any, propertyKey: string, parameterIndex: number) => void;
/**
 * 参数注解
 * @param message
 * @param property 验证属性
 * @constructor
 */
export declare function Validate(message: string, property?: Array<ValidationProperty>): (target: any, propertyKey: string, parameterIndex: number) => void;
/**
 * 属性注解
 * @param message
 * @param property 验证相关
 * @constructor
 */
export declare function Property(message: string, property?: Array<ValidationProperty>): (target: any, attr: any) => void;
/**
 * 依赖注入
 * @param value
 * @constructor
 */
export declare function Resource(value?: string): (target: any, propertyName: string) => void;
/**
 * 获取验证model的属性
 * @param fn
 */
export declare function getValidationModel(fn: Function): Array<ValidationProperty>;
/**
 * RequestMapping请求
 * @constructor
 * @param annotationBean
 */
export declare function Bean(annotationBean?: AnnotationBean): (target: Object, propertyKey: string, descriptor: PropertyDescriptor) => void;
