import { Page } from "../param/Page";
import { BaseService } from "../service/BaseService";
import { AxiosPromise } from "csap-axios";
import { ResponseManagerModel, Result } from "../model/Result";
import { BeanFactory } from "../BeanFactory";
import { MethodRequestFactory } from "../engine/MethodRequestFactory";
/**
 * 顶层baseController
 * T 表单类型
 * S 筛选类型
 * R 列表返回类型
 * ID 主键
 */
export default abstract class BaseController<Service extends BaseService<T, S, R, ID>, T, S extends Page, R, ID> extends MethodRequestFactory<T> implements BeanFactory {
    /**
     * 验证信息
     */
    validation: T | any;
    /**
     * 获取验证信息
     */
    getValidation(): T | any;
    /**
     * 必须重写 getService
     */
    abstract getService(): Service;
    /**
     * 获取表单验证的属性
     */
    abstract getFormValidate(): Array<T | Function>;
    /**
     * 新增
     * @returns {AxiosPromise}
     */
    insert(data: T): AxiosPromise<Result<boolean>>;
    /**
     * 删除
     * @returns {AxiosPromise}
     */
    deletes(ids: Array<ID>): AxiosPromise<Result<number>>;
    /**
     * 单条删除<根据主键删除>
     * @param id
     */
    delete(id: ID): AxiosPromise<Result<boolean>>;
    /**
     * 根据ID查询单调信息
     * @param id 查询详情的ID
     */
    findById(id: ID): AxiosPromise<Result<R>>;
    /**
     * 修改
     * @param data 修改的数据
     */
    update(data: T): AxiosPromise<Result<boolean>>;
    /**
     *  分页查询
     * @param data 查询的筛选的数据
     */
    queryManagerListPage(data?: S): AxiosPromise<Result<ResponseManagerModel<R>>>;
    /**
     *  分页查询
     * @param data 筛选数据
     * @returns {*|AxiosPromise}
     */
    queryListPage(data?: S): AxiosPromise<Result<Array<R>>>;
    /**
     * 不分页查询
     * @param data
     * @returns {*}
     */
    query(data?: S): AxiosPromise<Result<Array<R>>>;
}
